#############################################################################
#
# XLConnect
# Copyright (C) 2010-2013 Mirai Solutions GmbH
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.
#
#############################################################################

#############################################################################
#
# Wrapper function to read data from named regions in an Excel file in one
# line.
# 
# Author: Thomas Themel, Mirai Solutions GmbH
#
#############################################################################


readNamedRegionFromFile <- function(file, ...) {
  args <- list(...)
  args$object <- loadWorkbook(file, create = FALSE)
  do.call("readNamedRegion", args)
}
